@@ -76,14 +76,6 @@ urlpatterns += patterns('examples.views.jqueryui',
         name='richtemplates_examples_jqueryui_icons'),
 )
 
-# Ajaxed
-
-urlpatterns += patterns('examples.views.ajaxed',
-    url(r'^tasks-ajaxed/$',
-        view='task_list_ajaxed',
-        name='richtemplates_examples_task_list_ajaxed'),
-)
-
 urlpatterns += patterns('',
     url(r'^richtemplates/', include('richtemplates.urls')),
 )
